/* 	LocaleHelper.java
 *	Copyright 	(c) 2002-2007, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/* @#History
 * [When]		[Who]					[What]
 * 30-06-2007   dennis@brains2b.nl      fixes for javadoc		
*/
package org.brains2b.util;

import java.util.Locale;

/** 
 * A function library giving some extra help dealing with java.util.Locale.
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.10.1 [30-06-2007]
 * @since TwelBox 0.30
 */
public class LocaleHelper {

	/**
	 * gets Locale from a String representing a Locale
	 * <p> the String has the form of language_country as used by ResourceBundles
	 * and should comply to the two letter ISO definitions of language and country.
	 * <p>If the String default is supplied an empty Locale is returned.
	 * @param localeAbbr String, the String representing a locale. This function is case
	 * insensitive.
	 * @return Locale the Locale that could be determined. If it cannot be determined null
	 * is returned.
	 */
	public final static Locale getLocale(String localeAbbr) {
		
		if (localeAbbr!=null) {
			if (localeAbbr.equalsIgnoreCase("default")) return new Locale("","");
			int idx=localeAbbr.indexOf("_");
			if (idx!=-1) {
				String lang=localeAbbr.substring(0,idx).toLowerCase();
				String cntry=localeAbbr.substring(idx+1).toUpperCase();
				if (isLanguage(lang) && isCountry(cntry)) 
				return new Locale(lang,cntry);
			} else {
				String lang=localeAbbr.toLowerCase();
				if (isLanguage(lang)) 
				return new Locale(lang,"");
			}		
		} 
		return null;
	}
	
	/**
	 * Determines if a two letter combination is a valid ISO language code.
	 * @param isoLang String, the two letter String combination.
	 * @return boolean, true if the String combination is a valid ISO language code
	 */
	public final static boolean isLanguage(String isoLang) {
		return inList(isoLang,Locale.getISOLanguages());
	}
	
	/**
	 * Determines if a two letter combination is a valid ISO country code.
	 * @param isoLang String, the two letter String combination.
	 * @return boolean, true if the String combination is a valid ISO country code
	 */
	public final static boolean isCountry(String isoLang) {
		return inList(isoLang,Locale.getISOCountries());
	}

	/**
	 * Method inList.
	 * @param item
	 * @param list
	 * @return boolean
	 */
	private final static boolean inList(Object item, Object[] list) {
		if(item!=null && list!=null)
		for (int i=0;i<list.length;i++) {
			if (item.equals(list[i])) return true;
		}
		return false;
	}		
}
