/*  SortedMapTest.java
 *	Copyright 	(c) 2003, Brains2B.org
 *
 *	Created by: dennis
 *  Created on: Aug 22, 2003
 * 
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package test.org.brains2b.collection;

import java.util.Iterator;

import junit.framework.TestCase;

import org.brains2b.collection.MapEntry;
import org.brains2b.collection.SortedMap;

/** Unit test for org.brains2b.collection.SortedMap
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.1 [22-08-2003]
 */
public class SortedMapTest extends TestCase {
    private SortedMap m_map;

    /**
     * Constructor for SortedMapTest.
     * @param arg0
     */
    public SortedMapTest(String arg0) {
        super(arg0);
    }

    public static void main(String[] args) {
        junit.swingui.TestRunner.run(SortedMapTest.class);
    }

    protected void setUp() throws Exception {
        m_map = new SortedMap();
        for (int i = 0; i < 26; i++) {
            m_map.put(String.valueOf(i), String.valueOf((char)(90-i)));
        }
    }

    public void testGet() {
        assertEquals("Z", m_map.get("0"));
        assertEquals("A", m_map.get("25"));
        assertNull(m_map.get("100"));
        assertNull(m_map.get(null));
    }
    
    public void testSetSortOrder() {
        int cnt = 0;
        for (Iterator it = m_map.values().iterator();it.hasNext();) {
            assertEquals( String.valueOf((char)(90-cnt++)), it.next() );
        }
        m_map.setSortOrder(SortedMap.VALUE);
        cnt = 25;
        for (Iterator it = m_map.values().iterator();it.hasNext();) {
            assertEquals(String.valueOf((char)(90-cnt--)), it.next() );
        }
    }

    public void testCompare() {
        MapEntry one = new MapEntry("3","D");
        MapEntry two = new MapEntry("23","X");
        m_map.setSortOrder(SortedMap.NO_SORT);
        assertTrue(m_map.compare(one, two)==1);
        assertTrue(m_map.compare(one, one)==1);
        assertTrue(m_map.compare(one, null)==1);
        assertTrue(m_map.compare(one, "random")==1);
        m_map.setSortOrder(SortedMap.KEY);
        assertTrue(m_map.compare(one, two)>0);
        assertTrue(m_map.compare(one, one)==0);
        assertTrue(m_map.compare(two, one)<0);
        assertTrue(m_map.compare(one, null)==-1);
        assertTrue(m_map.compare(null, two)==1);
        assertTrue(m_map.compare("random",two)>0);
        assertTrue(m_map.compare(one,"random")<0);
         m_map.setSortOrder(SortedMap.VALUE);
        assertTrue(m_map.compare(one, two)<0);
        assertTrue(m_map.compare(one, one)==0);
        assertTrue(m_map.compare(two, one)>0);
        assertTrue(m_map.compare(one, null)==-1);
        assertTrue(m_map.compare(null, two)==1);
        assertTrue(m_map.compare("random",two)>0);
        assertTrue(m_map.compare(one,"random")<0);
    }

    public void testPutObjectObject() {
        m_map.put("-1", "@");
        m_map.setSortOrder(SortedMap.VALUE);
        
       assertTrue(m_map.containsKey("-1"));
       assertTrue(m_map.containsValue("@"));
       
       for (Iterator it= m_map.keySet().iterator();it.hasNext();) {
           assertEquals("-1",it.next());
           break;
       }
       
       m_map.setSortOrder(SortedMap.KEY);
        for (Iterator it= m_map.values().iterator();it.hasNext();) {
           assertEquals("@",it.next());
           break;
       } 
        assertEquals(27,m_map.size());
        m_map.put(null, "random");
        m_map.put("random", null);
        m_map.put(null, null    );
        assertEquals(27,m_map.size());
    }

    public void testRemoveObject() {
        assertEquals(26,m_map.size());
        m_map.remove("23");
        assertEquals(25,m_map.size());
        assertTrue(!m_map.containsKey("23"));
        
    }

}
