/* 	DateHelperTest.java
 * 
 * 	Created on: Dec 11, 2002
 * 	Created by: Dennis Groenendijk
 * 
 * Copyright (c) 2002, Brains2B.org
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that
 * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 /* @#History
 * [When]			[Who]							[What]
 * 17-01-2003	dennis@brains2b.nl	Included test for month =0
 * 24-04-2005	dennis@brains2b.nl	Included test for bug #699 01-11-2004
 * 27-04-2005	dennis@brains2b.nl	Make sure Locale is set correctly
 */
package test.org.brains2b.util;

import java.util.Calendar;
import java.util.Date;
import java.util.Locale;

import junit.framework.TestCase;

import org.brains2b.util.DateHelper;

/** Unit test for org.brains2b.util.DateHelper
 *  [Long description]
 *
 * @author <A HREF="MAILTO:dennis@brains2b.nl">dennis@brains2b.nl</A>
 * @version 0.11 [27-04-2005]
 * @see org.brains2b.util.DateHelper
 */
public class DateHelperTest extends TestCase {

	Calendar m_target=Calendar.getInstance();
        
    /**
     * Constructor for DateHelperTest.
     * @param arg0
     */
    public DateHelperTest(String arg0) {
        super(arg0);
    }

    public static void main(String[] args) {
       
        junit.swingui.TestRunner.run(DateHelperTest.class);
    }

    protected void setUp() throws Exception {
        super.setUp();
        Locale.setDefault(new Locale("nl","NL"));
    }
    
	public void testToDate_dd_mm_yyyy() {
		m_target.set(2003,2,29);
		assertTrue(equalDate(m_target.getTime(),DateHelper.toDate("29-03-2003")));	
	
		m_target.set(2003,1,28);
		assertTrue(equalDate(m_target.getTime(),DateHelper.toDate("28-02-2003")));	
		
		m_target.set(2003,0,29);
		assertTrue(equalDate(m_target.getTime(),DateHelper.toDate("29-01-2003")));	
		m_target.set(2004,10,01);
		assertTrue(equalDate(m_target.getTime(),DateHelper.toDate("01-11-2004")));	
	}
    
    public void testToDate() {
        m_target.set(2003,2,29);
        assertTrue(equalDate(m_target.getTime(),DateHelper.toDate("290303")));  
    
        m_target.set(2003,1,28);
        assertTrue(equalDate(m_target.getTime(),DateHelper.toDate("28022003")));  
        
        m_target.set(2003,0,29);
        assertTrue(equalDate(m_target.getTime(),DateHelper.toDate("29-01-03")));  
        m_target.set(2004,10,01);
        assertTrue(equalDate(m_target.getTime(),DateHelper.toDate("1.11.2004"))); 
        
        m_target.set(2007,06,20);
        assertTrue(equalDate(m_target.getTime(),DateHelper.toDate("20-07-2007")));  
          
    }
    
    public void testisoToDate() {
        m_target.clear();
        m_target.set(2005, 0,16);
        assertEquals(m_target.getTime(),DateHelper.isoToDate("2005-01-16"));
        m_target.set(2005,9,21,21,18,31);
        assertEquals(m_target.getTime(),DateHelper.isoToDate("2005-10-21T21:18:31.0"));
 
    }
    
    public void testIsoString() {
        m_target.clear();
        m_target.set(2005, 0,16);
        assertEquals("2005-01-16",DateHelper.isoFromDate(m_target.getTime()));
        m_target.set(2005,9,21,21,18,31);
        assertEquals("2005-10-21T21:18:31.0",DateHelper.isoFromDate(m_target.getTime(),true));
    }
	
	public void testFromDate() {
		m_target.set(2003,2,29);
		assertEquals("29-mrt-2003",DateHelper.fromDate(m_target.getTime()));	
	
		m_target.set(2003,1,28);
		assertEquals("28-feb-2003",DateHelper.fromDate(m_target.getTime()));	
		
		m_target.set(2003,0,29);
		assertEquals("29-jan-2003",DateHelper.fromDate(m_target.getTime()));	
		
		m_target.set(2004,10,01);
		assertEquals("01-nov-2004",DateHelper.fromDate(m_target.getTime()));	
	}
		
	private boolean equalDate(Date one, Date two) {
		Calendar cOne=Calendar.getInstance();
		Calendar cTwo=Calendar.getInstance();
		cOne.setTime(one);
		cTwo.setTime(two);
		if (cOne.get(Calendar.YEAR)==cTwo.get(Calendar.YEAR) 
			&& cOne.get(Calendar.MONTH)==cTwo.get(Calendar.MONTH)
			&& cOne.get(Calendar.DATE)==cTwo.get(Calendar.DATE)) {
				return true;
			} 
		return false;
	}
}
