/* 	GuiHelperTest.java
 *	Copyright (c) 2007, Brains2B.org
 *	
 *	Created by: Dennis Groenendijk
 *	Created on: Jun 26, 2007
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that  * the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and 
 * the following disclaimer. 
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 * the following disclaimer in the documentation and/or other materials provided with the distribution. 
 * 3. The name of the author may not be used to endorse or promote products derived from this software 
 * without specific prior written permission. 
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package test.org.brains2b.util;

import java.awt.Dimension;
import java.awt.Rectangle;

import org.brains2b.util.GuiHelper;

import junit.framework.TestCase;

public class GuiHelperTest extends TestCase {

    public void testSetMiddleRectangleRectangle() {
       Rectangle target=new Rectangle(0,0,100,100);
       Rectangle source=new Rectangle(10,10,650,390);
       assertEquals(new Rectangle(285,155,100,100),GuiHelper.setMiddle(target, source));
       try {
            GuiHelper.setMiddle(target, (Rectangle) null);
            assertTrue(false);
       } catch (IllegalArgumentException ieax) {
           assertTrue(true);
       }
       try {
           GuiHelper.setMiddle((Rectangle) null,source);
           assertTrue(false);
       } catch (IllegalArgumentException ieax) {
           assertTrue(true);
       }
       
    }

    public void testDecodeDimension() {
        assertNull(GuiHelper.decodeDimension(null));
        assertEquals(new Dimension(10,10) ,GuiHelper.decodeDimension("10,10"));
        assertEquals(new Dimension(10,-10),GuiHelper.decodeDimension("10,-10"));
    }

    public void testEncodeDimension() {
        assertNull(GuiHelper.encodeDimension(null));
        assertEquals("10,10",GuiHelper.encodeDimension(new Dimension(10,10)));
        assertEquals("10,-10",GuiHelper.encodeDimension(new Dimension(10,-10)));
    }

    public void testGetWidthString() {
       assertEquals(0,GuiHelper.getWidth(null));
       assertEquals(91,GuiHelper.getWidth("1234567890"));
       assertEquals(11,GuiHelper.getWidth(""));
       assertEquals(26,GuiHelper.getWidth("....."));
    }

    public void testGetWidthStringInt() {
       assertEquals(10,GuiHelper.getWidth(null,10));
       assertEquals(100,GuiHelper.getWidth("1234567890",100));
       assertEquals(91,GuiHelper.getWidth("1234567890",-123));
       assertEquals(11,GuiHelper.getWidth("",0));
    }

    public void testIsColor() {
        assertTrue(!GuiHelper.isColor(null));
        assertTrue( GuiHelper.isColor("#ffabc1"));
        assertTrue( GuiHelper.isColor("0xffabc1"));
        assertTrue(!GuiHelper.isColor(String.valueOf(Long.MAX_VALUE)));
        assertTrue(!GuiHelper.isColor(String.valueOf(Long.MIN_VALUE)));
        assertTrue(!GuiHelper.isColor("xyz"));
    }

    public void testIsFont() {
        assertTrue(!GuiHelper.isFont(null));
        assertTrue( GuiHelper.isFont("Dialog-12-PLAIN"));
        //Not really usefull, because test will always return true
    }

}
